Given index from hclust merge matrix, return X, Y row indices corresponding to groups specified by index
getMergeGroupRows(idx, groups, groupMerges)index from hclust merge
list of starting group membership (input to hierBipartite())
list of merged groups thus far (groupMerge[[3]] is a vector of group names from cluster created at third merge)
vector of row indices corresponding to X, Y