Given group indices for a merge from hclust merge matrix, return group names of merged cluster
newMergedGroup(idx1, idx2, groups, groupMerges)group index of first group from hclust merge
group index of second group from hclust merge
list of starting group membership (input to hierBipartite())
list of merged groups thus far (groupMerge[[3]] is a vector of group names from cluster created at third merge)
vector of group names after merge of group indicated by idx1 and idx2