Learn R Programming

hierBipartite (version 0.0.2)

null_distri: Null distribution of dissimilarity measures

Description

Generates null distribution of dissimilarity measures between group 1 (X1, Y1) and group 2 (X2, Y2).

Usage

null_distri(X1, Y1, X2, Y2, n.perm = 100, parallel = FALSE, maxCores = 7)

Arguments

X1

an n x p matrix of variable set 1 (e.g. gene expression) from group 1

Y1

an n x q matrix of variable set 2 (e.g. drug sensitivity) from group 1

X2

an n x p matrix of variable set 1 (e.g. gene expression) from group 2

Y2

an n x q matrix of varaible set 2 (e.g. drug sensitivity) from group 2

n.perm

number of null dissimilarity measures to generate

parallel

boolean for whether to parallelize permutation

maxCores

maximum number of cores to use (only applicable when parallel = TRUE)

Value

vector of length n.perm of null dissimilarity measures

Examples

Run this code
# NOT RUN {
# Get data for group squamous cell carcinoma, esophagus and for group
# squamous cell carcinoma, upper aerodigestive
data(ctrp2)

groups = ctrp2$groups
X = ctrp2$X
Y = ctrp2$Y

x1 = X[groups[["squamous_cell_carcinoma_esophagus"]], ]
y1 = Y[groups[["squamous_cell_carcinoma_esophagus"]], ]

x2 = X[groups[["squamous_cell_carcinoma_upper_aerodigestive"]], ]
y2 = Y[groups[["squamous_cell_carcinoma_upper_aerodigestive"]], ]

# }
# NOT RUN {
dissimilarities = null_distri(x1, y1, x2, y2, n.perm = 100)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab